// file      : examples/cxx/tree/library/driver.cxx
// author    : Boris Kolpackov <boris@codesynthesis.com>
// copyright : not copyrighted - public domain

#include <memory>   // std::auto_ptr
#include <iostream>

#include "schemas.hxx"

#include <xqilla/simple-api/XQilla.hpp>

using std::cerr;
using std::endl;

class XSDErrorHandler : public xml_schema::error_handler
{
  virtual bool handle (const std::basic_string<char>& id,
                       unsigned long line,
                       unsigned long column,
                       severity,
                       const std::basic_string<char>& message) {
    std::cerr
      << "[ParsingErrorHandler]: \""
      << message <<"\""
      << " in line: " << line
      << ", column: " << column
      << std::endl;

    return false;
  }
};

int
main (int argc, char* argv[])
{
  XQilla xqilla;

  if (argc != 2)
  {
    cerr << "usage: " << argv[0] << " library.xml" << endl;
    return 1;
  }

  try
  {
    // Read in the XML file and obtain its object model.
    //
    XSDErrorHandler eh;

     std::auto_ptr<ControlBasisType> cbt
       (::ControlBasis
        (argv[1], eh, xml_schema::flags::dont_validate));
  }
  catch (const xml_schema::exception& e)
  {
    cerr << e << endl;
    return 1;
  }
}
